appwrite library
Appwrite Flutter SDK
This SDK is compatible with Appwrite server version 1.9.x. For older versions, please check previous releases.
Classes
- Account
- The Account service allows you to authenticate and manage a user account.
- Avatars
- The Avatars service aims to help you complete everyday tasks related to your app image, icons, and avatars.
-
Channel<
T> - Channel class with generic type parameter for type-safe method chaining
- Client
- Client that handles requests to Appwrite.
- Databases
- The Databases service allows you to create structured collections of documents, query and filter lists of documents
- Functions
- The Functions Service allows you view, create and manage your Cloud Functions.
- Graphql
- The GraphQL API allows you to query and mutate your Appwrite server using GraphQL.
- ID
- Helper class to generate ID strings for resources.
- InputFile
- Helper class to handle files.
- Locale
- The Locale service allows you to customize your app based on your users' location.
- Messaging
- The Messaging service allows you to send messages to any provider type (SMTP, push notification, SMS, etc.).
- Operator
- Helper class to generate operator strings for atomic operations.
- Permission
- Helper class to generate permission strings for resources.
- Query
- Helper class to generate query strings.
- Realtime
- Realtime allows you to listen to any events on the server-side in realtime using the subscribe method.
- RealtimeMessage
- Realtime Message
- RealtimeSubscription
- Realtime Subscription
-
Response<
T> - Appwrite Response
- Role
- Helper class to generate role strings for Permission.
- Storage
- The Storage service allows you to manage your project files.
- TablesDB
- Teams
- The Teams service allows you to group users of your project and to enable them to share read and write access to your project resources
- UploadProgress
- Progress of a File Upload
Enums
- Condition
- Filter condition for array operations
Extensions
-
BucketChannel
on Channel<
_Bucket> - Only available on Channel<_Bucket>
-
CollectionChannel
on Channel<
_Collection> - Only available on Channel<_Collection>
-
DatabaseChannel
on Channel<
_Database> - Only available on Channel<_Database>
-
DocumentChannel
on Channel<
_Document> - Only available on Channel<_Document>
-
FileChannel
on Channel<
_File> - Only available on Channel<_File>
-
MembershipChannel
on Channel<
_Membership> - Only available on Channel<_Membership>
-
RowChannel
on Channel<
_Row> - Only available on Channel<_Row>
-
TableChannel
on Channel<
_Table> - Only available on Channel<_Table>
-
TablesDBChannel
on Channel<
_TablesDB> - Only available on Channel<_TablesDB>
-
TeamChannel
on Channel<
_Team> - Only available on Channel<_Team>
Exceptions / Errors
- AppwriteException
- Exception thrown by the appwrite package.