ImageGravity enum

Inheritance
Available extensions

Values

center → const ImageGravity
const ImageGravity(value: "center")
topLeft → const ImageGravity
const ImageGravity(value: "top-left")
top → const ImageGravity
const ImageGravity(value: "top")
topRight → const ImageGravity
const ImageGravity(value: "top-right")
left → const ImageGravity
const ImageGravity(value: "left")
const ImageGravity(value: "right")
bottomLeft → const ImageGravity
const ImageGravity(value: "bottom-left")
bottom → const ImageGravity
const ImageGravity(value: "bottom")
bottomRight → const ImageGravity
const ImageGravity(value: "bottom-right")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageGravity>
A constant List of the values in this enum, in order of their declaration.