AlgoArgon2 class

AlgoArgon2

Implemented types

Constructors

AlgoArgon2({required String type, required int memoryCost, required int timeCost, required int threads})
AlgoArgon2.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
memoryCost → int
Memory used to compute hash.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threads → int
Number of threads used to compute hash.
final
timeCost → int
Amount of time consumed to compute hash
final
type → String
Algo type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited