installationRedirectUrl property
URL users are redirected to after creating or updating an installation of this application. Empty for no redirect.
Implementation
final String installationRedirectUrl;
URL users are redirected to after creating or updating an installation of this application. Empty for no redirect.
final String installationRedirectUrl;