Execution class

Execution

Implemented types

Constructors

Execution({required String $id, required String $createdAt, required String $updatedAt, required List<String> $permissions, required String resourceId, required ExecutionResourceType resourceType, required String deploymentId, required ExecutionTrigger trigger, required ExecutionStatus status, required String requestMethod, required String requestPath, required List<Headers> requestHeaders, required int responseStatusCode, required String responseBody, required List<Headers> responseHeaders, required String logs, required String errors, required double duration, String? scheduledAt})
Execution.fromMap(Map<String, dynamic> map)
factory

Properties

$createdAt String
Execution creation date in ISO 8601 format.
final
$id String
Execution ID.
final
$permissions List<String>
Execution roles.
final
$updatedAt String
Execution update date in ISO 8601 format.
final
deploymentId String
Deployment ID used to create the execution.
final
duration double
Resource(function/site) execution duration in seconds.
final
errors String
Resource errors. Includes the last 4,000 characters. This will return an empty string unless the response is returned using an API key or as part of a webhook payload.
final
hashCode int
The hash code for this object.
no setterinherited
logs String
Resource logs. Includes the last 4,000 characters. This will return an empty string unless the response is returned using an API key or as part of a webhook payload.
final
requestHeaders List<Headers>
HTTP request headers as a key-value object. This will return only whitelisted headers. All headers are returned if execution is created as synchronous.
final
requestMethod String
HTTP request method type.
final
requestPath String
HTTP request path and query.
final
resourceId String
Function or site ID.
final
resourceType ExecutionResourceType
Execution resource type.
final
responseBody String
HTTP response body. This will return empty unless execution is created as synchronous.
final
responseHeaders List<Headers>
HTTP response headers as a key-value object. This will return only whitelisted headers. All headers are returned if execution is created as synchronous.
final
responseStatusCode int
HTTP response status code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt String?
The scheduled time for execution. If left empty, execution will be queued immediately.
final
status ExecutionStatus
The status of the resource execution. Possible values can be: waiting, processing, completed, failed, or scheduled.
final
trigger ExecutionTrigger
The trigger that caused the resource to execute. Possible values can be: http, schedule, or event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited