File class
File
- Implemented types
Constructors
-
File({required String $id, required String bucketId, required String $createdAt, required String $updatedAt, required List<
String> $permissions, required String name, required String folder, required String key, required String signature, required String mimeType, required int sizeOriginal, required int sizeActual, required int chunksTotal, required int chunksUploaded, required bool encryption, required String compression}) -
File.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
File creation date in ISO 8601 format.
final
- $id → String
-
File ID.
final
-
$permissions
→ List<
String> -
File permissions. Learn more about permissions.
final
- $updatedAt → String
-
File update date in ISO 8601 format.
final
- bucketId → String
-
Bucket ID.
final
- chunksTotal → int
-
Total number of chunks available
final
- chunksUploaded → int
-
Total number of chunks uploaded
final
- compression → String
-
Compression algorithm used for the file. Will be one of none, gzip, or zstd.
final
- encryption → bool
-
Whether file contents are encrypted at rest.
final
- folder → String
-
Virtual folder containing the file, with a trailing slash. Empty for the bucket root.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Full virtual path of the file: the folder followed by the file name.
final
- mimeType → String
-
File mime type.
final
- name → String
-
File name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
File MD5 signature.
final
- sizeActual → int
-
File actual stored size in bytes after compression and/or encryption.
final
- sizeOriginal → int
-
File original size in bytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited