Locale class
Locale
- Implemented types
Constructors
- Locale({required String ip, required String countryCode, required String country, required String continentCode, required String continent, required bool eu, required String currency, String? city, String? timeZone, String? postalCode, double? latitude, double? longitude, String? autonomousSystemNumber, String? autonomousSystemOrganization, String? isp, String? connectionType, String? connectionUsageType, String? connectionOrganization})
-
Locale.fromMap(Map<
String, dynamic> map) -
factory
Properties
- autonomousSystemNumber → String?
-
Autonomous System Number (ASN) of the IP
final
- autonomousSystemOrganization → String?
-
Organization that owns the ASN
final
- city → String?
-
City
final
- connectionOrganization → String?
-
Registered organization of the IP
final
- connectionType → String?
-
Connection type of the IP (e.g. cable, cellular, corporate)
final
- connectionUsageType → String?
-
User type classification of the IP (e.g. residential, business, hosting)
final
- continent → String
-
Continent name. This field support localization.
final
- continentCode → String
-
Continent code. A two character continent code "AF" for Africa, "AN" for Antarctica, "AS" for Asia, "EU" for Europe, "NA" for North America, "OC" for Oceania, and "SA" for South America.
final
- country → String
-
Country name. This field support localization.
final
- countryCode → String
-
Country code in ISO 3166-1 two-character format
final
- currency → String
-
Currency code in ISO 4217-1 three-character format
final
- eu → bool
-
True if country is part of the European Union.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ip → String
-
User IP address.
final
- isp → String?
-
Internet service provider of the IP
final
- latitude → double?
-
Latitude
final
- longitude → double?
-
Longitude
final
- postalCode → String?
-
Postal code
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeZone → String?
-
Name of timezone
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited