Membership class
Membership
- Implemented types
Constructors
-
Membership({required String $id, required String $createdAt, required String $updatedAt, required String userId, required String userName, required String userEmail, required String userPhone, required String teamId, required String teamName, required String invited, required String joined, required bool confirm, required bool mfa, required List<
String> roles}) -
Membership.fromMap(Map<
String, dynamic> map) -
factory
Properties
- $createdAt → String
-
Membership creation date in ISO 8601 format.
final
- $id → String
-
Membership ID.
final
- $updatedAt → String
-
Membership update date in ISO 8601 format.
final
- confirm → bool
-
User confirmation status, true if the user has joined the team or false otherwise.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invited → String
-
Date, the user has been invited to join the team in ISO 8601 format.
final
- joined → String
-
Date, the user has accepted the invitation to join the team in ISO 8601 format.
final
- mfa → bool
-
Multi factor authentication status, true if the user has MFA enabled or false otherwise. Hide this attribute by toggling membership privacy in the Console.
final
-
roles
→ List<
String> -
User list of roles
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamId → String
-
Team ID.
final
- teamName → String
-
Team name.
final
- userEmail → String
-
User email address. Hide this attribute by toggling membership privacy in the Console.
final
- userId → String
-
User ID.
final
- userName → String
-
User name. Hide this attribute by toggling membership privacy in the Console.
final
- userPhone → String
-
User phone number. Hide this attribute by toggling membership privacy in the Console.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited