userPhone property
User phone number. Hide this attribute by toggling membership privacy in the Console.
Implementation
final String userPhone;
User phone number. Hide this attribute by toggling membership privacy in the Console.
final String userPhone;