PresenceList class

Presences List

Implemented types

Constructors

PresenceList({required int total, required List<Presence> presences})
PresenceList.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
presences List<Presence>
List of presences.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of presences that matched your query.
final

Methods

convertTo<T>(T fromJson(Map)) List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited