Client class abstract

Client that handles requests to Appwrite.

The Client is also responsible for managing user's sessions.

Implementers

Constructors

Client({String endPoint = 'https://cloud.appwrite.io/v1', bool selfSigned = false})
Initializes a Client.
factory

Properties

config Map<String, String>
Holds configuration such as project.
getter/setter pair
endPoint String
Appwrite endpoint.
no setter
endPointRealtime String?
Appwrite realtime endpoint.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHeader(String key, String value) Client
Add headers that should be sent with all API calls.
call(HttpMethod method, {String path = '', Map<String, String> headers = const {}, Map<String, dynamic> params = const {}, ResponseType? responseType}) Future<Response>
Send the API request.
chunkedUpload({required String path, required Map<String, dynamic> params, required String paramName, required String idParamName, required Map<String, String> headers, dynamic onProgress(UploadProgress)?}) Future<Response>
Upload a file in chunks.
getHeaders() Map<String, String>
Get the current request headers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ping() Future<String>
Send a ping to project as part of onboarding.
setBearer(String value) Client
Set Bearer.
setCookie(String value) Client
Set Cookie.
setDevKey(String value) Client
Set DevKey.
setEndpoint(String endPoint) Client
Set the Appwrite endpoint.
setEndPointRealtime(String endPoint) Client
Set the Appwrite realtime endpoint.
setImpersonateUserEmail(String value) Client
Set ImpersonateUserEmail.
setImpersonateUserId(String value) Client
Set ImpersonateUserId.
setImpersonateUserPhone(String value) Client
Set ImpersonateUserPhone.
setJWT(String value) Client
Set JWT.
setLocale(String value) Client
Set Locale.
setProject(String value) Client
Set Project.
setSelfSigned({bool status = true}) Client
Set self signed to status.
setSession(String value) Client
Set Session.
toString() String
A string representation of this object.
inherited
webAuth(Uri url, {String? callbackUrlScheme}) Future
Handle OAuth2 session creation.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chunkSize → const int
The size for chunked uploads in bytes.