Realtime class abstract
Realtime allows you to listen to any events on the server-side in realtime using the subscribe method.
- Implementers
Properties
- client → Client
-
finalinherited
- closeCode → int?
-
The close code set when the WebSocket connection is closed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disconnect(
) → Future< void> - Close the WebSocket connection and drop all active subscriptions client-side. Use this instead of calling RealtimeSubscription.unsubscribe on every subscription when you want to tear everything down.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
List< Object> channels, {List<String> queries = const []}) → RealtimeSubscription -
Subscribes to Appwrite events and returns a
RealtimeSubscriptionobject, which can be used to listen to events on the channels in realtime and to close the subscription to stop listening. -
toString(
) → String -
A string representation of this object.
inherited
-
upsertPresence(
{required String status, required String presenceId, List< String> ? permissions, Map<String, dynamic> ? metadata}) → void - Create or upsert a presence entry for the current authenticated user over the existing realtime connection.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited