Role class

Helper class to generate role strings for Permission.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

any() → String
Grants access to anyone.
guests() → String
Grants access to any guest user without a session.
label(String name) → String
Grants access to a user with the specified label.
member(String id) → String
Grants access to a specific member of a team.
team(String id, [String role = '']) → String
Grants access to a team by team ID.
user(String id, [String status = '']) → String
Grants access to a specific user by user ID.
users([String status = '']) → String
Grants access to any authenticated or anonymous user.