UploadProgress class

Progress of a File Upload

Constructors

UploadProgress({required String $id, required double progress, required int sizeUploaded, required int chunksTotal, required int chunksUploaded})
Initializes an UploadProgress
UploadProgress.fromJson(String source)
Initializes an UploadProgress from a JSON String
factory
UploadProgress.fromMap(Map<String, dynamic> map)
Initializes an UploadProgress from a Map<String, dynamic>
factory

Properties

$id → String
ID of the file.
final
chunksTotal → int
Total number of chunks.
final
chunksUploaded → int
Number of chunks uploaded.
final
hashCode → int
The hash code for this object.
no setteroverride
progress → double
Progress percentage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeUploaded → int
Size uploaded in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
Converts an UploadProgress to a JSON String
toMap() → Map<String, dynamic>
Converts an UploadProgress to a Map<String, dynamic>
toString() → String
Returns a string representation of an UploadProgress
override

Operators

operator ==(Object other) → bool
The equality operator.
override