ClientBrowser class

Implemented types

Constructors

ClientBrowser({String endPoint = 'https://cloud.appwrite.io/v1', bool selfSigned = false})

Properties

config Map<String, String>
Holds configuration such as project.
getter/setter pairoverride
endPoint String
Appwrite endpoint.
no setteroverride
endPointRealtime String?
Appwrite realtime endpoint.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHeader(String key, String value) ClientBrowser
Add headers that should be sent with all API calls.
call(HttpMethod method, {String path = '', Map<String, String> headers = const {}, Map<String, dynamic> params = const {}, ResponseType? responseType}) Future<Response>
Send the API request.
chunkedUpload({required String path, required Map<String, dynamic> params, required String paramName, required String idParamName, required Map<String, String> headers, dynamic onProgress(UploadProgress)?}) Future<Response>
Upload a file in chunks.
override
getHeaders() Map<String, String>
Get the current request headers.
init() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ping() Future<String>
Send a ping to project as part of onboarding.
inherited
prepareRequest(HttpMethod method, {required Uri uri, required Map<String, String> headers, required Map<String, dynamic> params}) → BaseRequest
inherited
prepareResponse(Response res, {ResponseType? responseType}) Response
inherited
setCookie(String value) ClientBrowser
The user cookie to authenticate with. Used by SDKs that forward an incoming Cookie header in server-side runtimes.
setDevKey(String value) ClientBrowser
Your secret dev API key
setEndpoint(String endPoint) ClientBrowser
Set the Appwrite endpoint.
setEndPointRealtime(String endPoint) ClientBrowser
Set the Appwrite realtime endpoint.
setImpersonateUserEmail(String value) ClientBrowser
Impersonate a user by email
setImpersonateUserId(String value) ClientBrowser
Impersonate a user by ID
setImpersonateUserPhone(String value) ClientBrowser
Impersonate a user by phone
setJWT(String value) ClientBrowser
Your secret JSON Web Token
setLocale(String value) ClientBrowser
Set Locale.
setProject(String value) ClientBrowser
Your project ID
setSelfSigned({bool status = true}) ClientBrowser
Set self signed to status.
setSession(String value) ClientBrowser
The user session to authenticate with
toResponse(StreamedResponse streamedResponse) Future<Response>
inherited
toString() String
A string representation of this object.
inherited
webAuth(Uri url, {String? callbackUrlScheme}) Future
Handle OAuth2 session creation.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chunkSize → const int