Browser enum
Values
- avantBrowser → const Browser
-
const Browser(value: "aa") - androidWebViewBeta → const Browser
-
const Browser(value: "an") - googleChrome → const Browser
-
const Browser(value: "ch") - googleChromeIOS → const Browser
-
const Browser(value: "ci") - googleChromeMobile → const Browser
-
const Browser(value: "cm") - chromium → const Browser
-
const Browser(value: "cr") - mozillaFirefox → const Browser
-
const Browser(value: "ff") - safari → const Browser
-
const Browser(value: "sf") - mobileSafari → const Browser
-
const Browser(value: "mf") - microsoftEdge → const Browser
-
const Browser(value: "ps") - microsoftEdgeIOS → const Browser
-
const Browser(value: "oi") - operaMini → const Browser
-
const Browser(value: "om") - opera → const Browser
-
const Browser(value: "op") - operaNext → const Browser
-
const Browser(value: "on")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited