Presence class
Presence
- Implemented types
Constructors
Properties
- $createdAt → String
-
Presence creation date in ISO 8601 format.
final
- $id → String
-
Presence ID.
final
-
$permissions
→ List<
String> -
Presence permissions. Learn more about permissions.
final
- $updatedAt → String
-
Presence update date in ISO 8601 format.
final
- expiresAt → String?
-
Presence expiry date in ISO 8601 format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
Presence source.
final
- status → String?
-
Presence status.
final
- userId → String
-
User ID.
final
Methods
-
convertTo<
T> (T fromJson(Map< String, dynamic> )) → T -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited